##  Scheduling Changes
You can schedule a change for fact sheet attributes to update their values at a future date. Scheduling the change creates a corresponding transformation item, making it part of your transformation initiative.
